from cytnx_core import Type


def test_type():
    assert isinstance(Type.Void, Type)
    assert isinstance(Type.Bool, Type)
    assert isinstance(Type.Uint16, Type)
    assert isinstance(Type.Int16, Type)
    assert isinstance(Type.Uint32, Type)
    assert isinstance(Type.Int32, Type)
    assert isinstance(Type.Uint64, Type)
    assert isinstance(Type.Int64, Type)
    assert isinstance(Type.Float, Type)
    assert isinstance(Type.Double, Type)
    assert isinstance(Type.ComplexFloat, Type)
    assert isinstance(Type.ComplexDouble, Type)



from __future__ import annotations

from enum import Enum

from . import device as device

class Type(Enum):
    @property
    def Void(self) -> int: ...
    @property
    def Bool(self) -> int: ...
    @property
    def Uint16(self) -> int: ...
    @property
    def Int16(self) -> int: ...
    @property
    def Uint32(self) -> int: ...
    @property
    def Int32(self) -> int: ...
    @property
    def Uint64(self) -> int: ...
    @property
    def Int64(self) -> int: ...
    @property
    def Float(self) -> int: ...
    @property
    def Double(self) -> int: ...
    @property
    def ComplexFloat(self) -> int: ...
    @property
    def ComplexDouble(self) -> int: ...



from cytnx_core import device


def test_device():
    assert isinstance(device.Cpu, int)
    assert isinstance(device.Cuda, int)
    assert isinstance(device.Ngpus, int)
    assert isinstance(device.Ncpus, int)


def test_device_prop():
    device.print_property()


def test_getname():
    name = device.getname(device.Cpu)
    assert isinstance(name, str)
